<?php

namespace Drupal\totext\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class ConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'totext_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['totext.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $credit_count = totext_get_credit_count();
    if ($credit_count) {
      $form['totext_count'] = [
        '#markup' => '<p>' . \Drupal::translation()->formatPlural($credit_count, 'You have <strong>1 credit</strong> remaining', 'You have <strong>@count credits</strong> remaining') . '</p>',
      ];
    }
    $form['totext_username'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#title' => $this->t('ToText username'),
      '#description' => $this->t('Your ToText <strong>API username</strong>, which is not the same as your administrative username.'),
      '#default_value' => $this->config('totext.settings')->get('totext_username'),
    ];
    $form['totext_password'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#title' => $this->t('ToText password'),
      '#description' => $this->t('Your ToText <strong>API password</strong>, which is not the same as your administrative password.'),
      '#default_value' => $this->config('totext.settings')->get('totext_password'),
    ];
    $form['totext_logging'] = [
      '#type' => 'radios',
      '#required' => TRUE,
      '#title' => $this->t('Logging level'),
      '#options' => [
        'error' => $this->t('Errors only'),
        'info' => $this->t('Errors and successful sends'),
      ],
      '#default_value' => $this->config('totext.settings')->get('totext_logging'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::configFactory()->getEditable('totext.settings');
    $config->set('totext_username', $form_state->getValue('totext_username'));
    $config->set('totext_password', $form_state->getValue('totext_password'));
    $config->set('totext_logging', $form_state->getValue('totext_logging'));
    $config->save();
    parent::submitForm($form, $form_state);
  }

}


